import tkinter as tk
from tkinter import ttk
from tkinter.messagebox import showinfo
from tkinter import  *
from graph import Graph
import textwrap
from PIL import Image, ImageTk
from route_finder import get_adjacent_list

#source env/bin/activate

# List with all the stations
data = get_adjacent_list()
stations = list(data[1].keys())
lines = get_adjacent_list()[2]

# Create main window
root = tk.Tk()
root.geometry('1000x1000')
root.title('Route Finder')

# Add an image
#image_path = "/Users/javier/Desktop/route-finder-app-master/metro-kiev.png"  # your own route here
image_path = input("Please enter the image path: ")

image = Image.open(image_path)
image = image.resize((600, 400))
photo = ImageTk.PhotoImage(image)

image_label = tk.Label(root, image=photo)
image_label.image = photo
image_label.pack(fill=tk.X, padx=5, pady=5)

# Origin input
origin_label = ttk.Label(text='Origin', font='Courier')
origin_label.pack(fill=tk.X, padx=5, pady=5)

combobox_values = []
for line, line_stations in lines.items():
    combobox_values.append('---' + line + '---')
    combobox_values.extend(line_stations)


selected_origin = tk.StringVar()
origin_combo = ttk.Combobox(root, textvariable=selected_origin)


origin_combo['values'] = tuple(combobox_values)

# To prevent writing in the input
origin_combo['state'] = 'readonly'
origin_combo.pack(fill=tk.X, padx=5, pady=5)

# Destination input
destination_label = ttk.Label(text='Destination', font='Courier')
destination_label.pack(fill=tk.X, padx=5, pady=5)

selected_destination = tk.StringVar()
destination_combo = ttk.Combobox(root, textvariable=selected_destination)

destination_combo['values'] = tuple(combobox_values)

# To prevent writing in the input
destination_combo['state'] = 'readonly'
destination_combo.pack(fill=tk.X, padx=5, pady=5)

# Close window
def close():
   root.quit()

def show_optimal_route() -> None:
    """ Show the optimal route """
    search_text = ''

    if origin_combo.get() and destination_combo.get():
        origin = origin_combo.get()
        destination = destination_combo.get()

        adjacent_list, stations, lines = get_adjacent_list()

        graph = Graph(adjacent_list, stations, lines)

        result = graph.a_star_search(origin, destination)

        for station in result:
            search_text += f'{station} - '
        search_text = textwrap.fill(search_text, width=90)

        search_result.configure(text=f'{search_text}', fg='#222')
    else:
        search_result.configure(text=f'It is neccesary to choose a station', fg='#f22')

# Create button
ttk.Button(root, text= "Show route",width= 20, command= show_optimal_route).pack(pady=20)


# Show the result
label=Label(root, text="Result:", font=("Courier 16 bold"))
label.pack()
search_result=Label(root, text="", font=("Courier 13 bold"))
search_result.pack()

ttk.Button(root, text= "Exit",width= 20, command= close).pack(pady=5)

if __name__ == '__main__':
    root.mainloop()
