from graph import Graph
import pathlib
import os
import geopy.distance
import json

def read_data(filename='data.json') -> dict:
    """
    To read data.json and retrieve the object with data
    """
    #Cargar datos del archivo json
    configFilePath = pathlib.Path(os.getcwd()) / filename
    with open(configFilePath, 'r') as configdata:
        data=configdata.read()

    return json.loads(data)

def get_neighbours(name: str, data: dict) -> list:
    """
    To obtain a list of pairs (name, distance in meters) of adjacent stations for a given station
    """
    neighbours = []
    origin_coordinates = tuple(data[name]['coordinates'])
    for station in data[name]['adjacent_stations']:
        destination_coordinates = tuple(data[station]['coordinates'])
        neighbour = (station, geopy.distance.geodesic(origin_coordinates, destination_coordinates).m)
        neighbours.append(neighbour)
    return neighbours

def get_adjacent_list() -> (dict, dict, dict):
    """
    Convert the data into the appropriate format.
    Returns:
        The adjacency list with distances between nodes: dict
        The stations with their coordinates: dict
        The lines and their stations: dict
    """
    adj_list = {}
    data = read_data()
    stations = data['subway_stations']
    lines = data['lines']
    for name, data in stations.items():
        adj_list[name] = get_neighbours(name, stations)
    return adj_list, stations, lines
